@@ -36,5 +36,7 @@ kmnotions <- function(x) {
   }
   rownames(sr) <- colnames(x)
   colnames(sr) <- colnames(x)
-  unique(sr)
+  red <-unique(sr)
+  class(red) <- unique(c("kmstructure", "kmfamily", class(red)))
+  red
 }
